# File Typer

Append extension in files without-it, based on mimetypes
Some files comes without any extension and windows comply
about it! Because of that, several tools, including Windows Explorer cannot
show the users the file preview, and cannot open-it.

This tool allows the user pass an directory/file and traverse-it, renaming
files, putting extension of known table into-it, based on mimetypes
